@@ -1,17 +1,18 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
+"""minos.networks.discovery.connectors module."""
 
 from __future__ import (
     annotations,
 )
 
 import logging
+from itertools import (
+    chain,
+)
+from operator import (
+    itemgetter,
+)
 from typing import (
+    Any,
     NoReturn,
 )
 
@@ -20,6 +21,9 @@ from minos.common import (
     MinosSetup,
 )
 
+from ..decorators import (
+    EnrouteAnalyzer,
+)
 from ..utils import (
     get_host_ip,
 )
@@ -33,7 +37,7 @@ logger = logging.getLogger(__name__)
 class DiscoveryConnector(MinosSetup):
     """Discovery Connector class."""
 
-    def __init__(self, client, name: str, host: str, port: int, *args, **kwargs):
+    def __init__(self, client, name: str, host: str, port: int, endpoints: list[dict[str, Any]], *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         self.client = client
@@ -41,6 +45,7 @@ class DiscoveryConnector(MinosSetup):
         self.name = name
         self.host = host
         self.port = port
+        self.endpoints = endpoints
 
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> DiscoveryConnector:
@@ -48,7 +53,20 @@ class DiscoveryConnector(MinosSetup):
         port = config.rest.port
         name = config.service.name
         host = get_host_ip()
-        return cls(client=client, name=name, host=host, port=port, *args, **kwargs)
+        endpoints = cls._endpoints_from_config(config)
+
+        return cls(client, name, host, port, endpoints, *args, **kwargs)
+
+    @staticmethod
+    def _endpoints_from_config(config: MinosConfig) -> list[dict[str, Any]]:
+        command_decorators = EnrouteAnalyzer(config.commands.service).get_rest_command_query()
+        query_decorators = EnrouteAnalyzer(config.queries.service).get_rest_command_query()
+
+        endpoints = chain(chain(*command_decorators.values()), chain(*query_decorators.values()))
+        endpoints = set(endpoints)
+        endpoints = [{"url": decorator.url, "method": decorator.method} for decorator in endpoints]
+        endpoints.sort(key=itemgetter("url", "method"))
+        return endpoints
 
     async def _setup(self) -> NoReturn:
         await self.subscribe()
@@ -59,7 +77,7 @@ class DiscoveryConnector(MinosSetup):
         :return: This method does not return anything.
         """
         logger.info("Performing discovery subscription...")
-        await self.client.subscribe(self.host, self.port, self.name)
+        await self.client.subscribe(self.host, self.port, self.name, self.endpoints)
 
     async def _destroy(self) -> NoReturn:
         await self.unsubscribe()
