@@ -82,16 +82,16 @@ class CommandHandler(Handler):
 
         return cls(handlers=handlers, **config.broker.queue._asdict(), **kwargs)
 
-    async def dispatch_one(self, entry: HandlerEntry) -> NoReturn:
+    async def dispatch_one(self, entry: HandlerEntry[Command]) -> NoReturn:
         """Dispatch one row.
 
         :param entry: Entry to be dispatched.
         :return: This method does not return anything.
         """
-        command = entry.data
-        logger.info(f"Dispatching '{command!s}'...")
+        logger.info(f"Dispatching '{entry!s}'...")
 
         fn = self.get_callback(entry.callback)
+        command = entry.data
         items, status = await fn(command)
 
         await self.broker.send(items, topic=command.reply_topic, saga=command.saga, status=status)
