@@ -6,8 +6,8 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-from .builders import (
-    RestBuilder,
+from .handlers import (
+    RestHandler,
 )
 from .messages import (
     RestRequest,
